DartCryptography class

An implementation of Cryptography in pure Dart.

Algorithms

The following algorithms are supported:

SHA-1/SHA-2 implementations use package:crypto, a package maintained by Google.

Inheritance
Implementers

Constructors

DartCryptography()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aesCbc({required MacAlgorithm macAlgorithm, int secretKeyLength = 32}) → AesCbc
override
aesCtr({required MacAlgorithm macAlgorithm, int secretKeyLength = 32, int counterBits = 64}) → AesCtr
override
aesGcm({int secretKeyLength = 32, int nonceLength = 12}) → AesGcm
override
argon2id({required int parallelism, required int memorySize, required int iterations, required int hashLength}) → Argon2id
override
blake2b() → Blake2b
override
blake2s() → Blake2s
override
chacha20({required MacAlgorithm macAlgorithm}) → Chacha20
override
chacha20Poly1305Aead() → Chacha20
override
ecdhP256({required int length}) → Ecdh
override
ecdhP384({required int length}) → Ecdh
override
ecdhP521({required int length}) → Ecdh
override
ecdsaP256(HashAlgorithm hashAlgorithm) → Ecdsa
override
ecdsaP384(HashAlgorithm hashAlgorithm) → Ecdsa
override
ecdsaP521(HashAlgorithm hashAlgorithm) → Ecdsa
override
ed25519() → Ed25519
override
hchacha20() → Hchacha20
override
hkdf({required Hmac hmac, required int outputLength}) → Hkdf
override
hmac(HashAlgorithm hashAlgorithm) → Hmac
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pbkdf2({required MacAlgorithm macAlgorithm, required int iterations, required int bits}) → Pbkdf2
override
poly1305() → Poly1305
override
rsaPss(HashAlgorithm hashAlgorithm, {required int nonceLengthInBytes}) → RsaPss
override
rsaSsaPkcs1v15(HashAlgorithm hashAlgorithm) → RsaSsaPkcs1v15
override
sha1() → Sha1
override
sha224() → Sha224
override
sha256() → Sha256
override
sha384() → Sha384
override
sha512() → Sha512
override
toString() → String
A string representation of this object.
inherited
x25519() → X25519
override
xchacha20({required MacAlgorithm macAlgorithm}) → Xchacha20
override
xchacha20Poly1305Aead() → Xchacha20
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultInstance → DartCryptography
final