DelegatingCipher class abstract

Implemented types
Implementers

Constructors

DelegatingCipher()

Properties

fallback → Cipher
no setter
hashCode → int
The hash code for this object.
no setterinherited
macAlgorithm → MacAlgorithm
Message authentication code (MacAlgorithm) used by the cipher.
no setteroverride
nonceLength → int
Number of bytes in the nonce ("Initialization Vector", "IV", "salt").
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKeyLength → int
Number of bytes in the SecretKey.
no setteroverride

Methods

decrypt(SecretBox secretBox, {required SecretKey secretKey, List<int> aad = const <int>[]}) → Future<List<int>>
Decrypts SecretBox and returns the bytes.
override
encrypt(List<int> clearText, {required SecretKey secretKey, List<int>? nonce, List<int> aad = const <int>[]}) → Future<SecretBox>
Encrypts bytes and returns SecretBox. Authenticates SecretBox with macAlgorithm, decrypts it, and returns the cleartext.
override
newNonce() → List<int>
Generates a new nonce with the correct length (nonceLength).
override
newSecretKey() → Future<SecretKey>
Generates a new SecretKey with the correct length (secretKeyLength).
override
newSecretKeyFromBytes(List<int> bytes) → Future<SecretKey>
Constructs a new SecretKey from the bytes.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited