DelegatingEcdsa class abstract

Inheritance
Implemented types

Constructors

DelegatingEcdsa()
const

Properties

fallback → Ecdsa
no setteroverride
hashAlgorithm → HashAlgorithm
Used hash algorithm.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
keyPairType → KeyPairType<KeyPairData, PublicKey>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

newKeyPair() → Future<EcKeyPair>
Generates a new KeyPair for this algorithm.
override
newKeyPairFromSeed(List<int> bytes) → Future<EcKeyPair>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(List<int> data, {required KeyPair keyPair}) → Future<Signature>
Calculates signature for the message.
inherited
toString() → String
A string representation of this object.
inherited
verify(List<int> data, {required Signature signature}) → Future<bool>
Verifies the signature.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited